Crate bugrep

Crate bugrep 

bugrep

a collection of utilities to return lines containing passed queries as well as print them to standard output.

Structs

Config

Functions

run
Prints out the lines containing the query
search
Returns a vector with the lines containing the passed query
search_case_insensitive
Returns the lines containing the passed query regardless of the casing